@@ -26,14 +26,11 @@
 #' }
 get_stats_user <- function(api_key, user_id)
 {
-  # SUPORT DATA FRAME WITH
-  #suport <- readRDS("data/suport.rds")#
-
   # COLLECT THE PROFILE BY USER NAME OR BY USER ID
   # it will depend on the type of user_id
   if(is.na(as.numeric(user_id)))
   {
-    user_id <- as.character(as.vector(csgo_api_profile(api_key, user_id, name = TRUE)))
+    user_id <- as.character(as.vector(csgo_api_profile(api_key, user_id, name = TRUE)))[1]
   } else{
     user_id <- as.character(user_id)
   }
@@ -46,13 +43,20 @@ get_stats_user <- function(api_key, user_id)
   # INCLUDING LABELS AND CATEGORIES
   stats <- fuzzyjoin::fuzzy_left_join(
     stats,
-    suport,
+    support,
     by = c('name' = 'name_match'),
     match_fun = stringr::str_detect)
 
+  # REMOVE DUPLICATES
+  aux <- stats %>%
+    dplyr::filter(stats$type == 'maps', stats$name_match == 'dust2')
+
   stats <- stats %>%
+    dplyr::anti_join(aux, by = c("value"="value")) %>%
+    dplyr::bind_rows(aux) %>%
     dplyr::mutate(player_name = profile_name)
 
+
   # RETURN
   return(stats)
 }
